@@ -1,27 +1,27 @@
 /*
    +----------------------------------------------------------------------+
-   | PHP version 4.0                                                      |
+   | PHP version 5                                                        |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2001 The PHP Group                                |
+   | Copyright (c) 2003-2021 Uwe Steinmann                                |
    +----------------------------------------------------------------------+
-   | This source file is subject to version 2.02 of the PHP license,      |
+   | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
-   | available at through the world-wide-web at                           |
-   | http://www.php.net/license/2_02.txt.                                 |
+   | available through the world-wide-web at the following url:           |
+   | http://www.php.net/license/3_01.txt                                  |
    | If you did not receive a copy of the PHP license and are unable to   |
    | obtain it through the world-wide-web, please send a note to          |
    | license@php.net so we can mail you a copy immediately.               |
    +----------------------------------------------------------------------+
-   | Authors: Uwe Steinmann <Uwe.Steinmann@fernuni-hagen.de>              |
+   | Authors: Uwe Steinmann <steinm@debian.org>                           |
    +----------------------------------------------------------------------+
 */
 
-/* $Id: php_ps.h 339465 2016-06-23 18:44:52Z steinm $ */
+/* $Id$ */
 
 #ifndef PHP_PS_H
 #define PHP_PS_H
 
-#define PHP_PS_VERSION "1.4.0"
+#define PHP_PS_VERSION "1.4.4"
 
 #ifdef PHP_WIN32
 #define PHP_PS_API __declspec(dllexport)
@@ -31,6 +31,10 @@
 
 #if HAVE_PS
 
+#if PHP_VERSION_ID >= 80000
+  #define HAVE_LOCALE_H
+#endif
+
 #include <libps/pslib.h>
 
 extern zend_module_entry ps_module_entry;
